/**
 * Interface for interacting with the page-level controls
 * that are provided in the admin menu.
 *
 */

"use strict";

window.PageControls = window.PageControls || {};

window.PageControls.Add = data => {
	//console.log(data);

	let control = document.createElement('li'),
		link = document.createElement('a'),
		target = document.getElementById('page-controls').querySelector('ul'),
		html = '';

	if(data.icon) {
		html += '<i class="icon icon-' + data.icon + '"></i>';
	}

	if(data.text) {
		html += '<span>' + data.text + '</span>';
	}
	else if(data.title) {
		html += '<span>' + data.title + '</span>';
	}

	link.href = data.href || '#';
	link.title = data.title || '';

	link.innerHTML = html;

	control.appendChild(link);

	if(data.weight) {
		let controlAdded = false;
		control.dataset.controlWeight = data.weight;

		// Put the icon in the correct position
		target.childNodes.forEach(el => {
			let elWeight = el.dataset.controlWeight || 99;
			if(elWeight >= data.weight) {
				controlAdded = true;
				target.insertBefore(control, el);
				return false;
			}
		});

		if(!controlAdded) {
			// Just append to end of list
			target.appendChild(control);
		}
	}
	else {
		target.appendChild(control);
	}

	if(typeof(data.click) === 'function') {
		link.addEventListener('click', evt => {
			data.click();
			evt.preventDefault();
		});
	}
}