<?php


namespace Favicon;


use Core\ConfigHandler;
use Core\Filestore\Factory;
use Core\Filestore\File;

class FaviconHelper {
	/**
	 * Get an array of all favicons that have been set on this site
	 *
	 * @return File[]
	 *
	 * @throws \Exception
	 */
	public static function GetFaviconSizes() : array {
		$files = [];

		$image = ConfigHandler::Get('/favicon/image');
		if($image){
			$closestLargest = Factory::File($image);
		}
		else{
			// Check the theme default.
			// This component ships with one by default, and the theme is free to include their own,
			// (which will override this version.)
			$closestLargest = Factory::File('asset/images/favicon.png');
		}

		if(!($closestLargest->exists() && $closestLargest->isReadable())){
			// Ensure that the no-page-available icon doesn't show if there is no favicon set!
			$closestLargest = null;
		}

		// All sizes of supported favicons, in descending order!
		$sizes = [
			'512', // Google PWA
			'256', // Google PWA
			'196', // Android Chrome
			'192', // Google PWA
			'180', // iPhone 6 Plus IOS 8+
			'152', // iPad w/Retina IOS 7
			'120', // iPhone w/Retina IOS 7
			'96', // Google TV
			'76', // iPad IOS 7
			'64', // Nix Desktop
			'60', // iPhone IOS 7
			'48', // Win Desktop
			'32', // Win Task Bar Icon
			'16', // Chrome,IE,FF Tab Icon
		];

		foreach($sizes as $s){
			// Get the specific image for this device and this size, (if it exists).
			if(($val = ConfigHandler::Get('/favicon/image-' . $s))){
				$img = Factory::File($val);
				if($img->exists() && $img->isReadable()){
					// This image is good!
					$closestLargest = $img;
				}
			}

			if($closestLargest){
				$files[ $s ] = $closestLargest;
			}
		}

		return $files;
	}
}