<?php
/**
 * File for class Lookup definition in the coreplus project
 * 
 * @package geocode
 * @author Charlie Powell <charlie@evalagency.com>
 * @date 20140327.0647
 * @copyright Copyright (C) 2009-2017  Charlie Powell
 * @license GNU Affero General Public License v3 <http://www.gnu.org/licenses/agpl-3.0.txt>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/agpl-3.0.txt.
 */

namespace GeoLookup;

use Core\Filestore\Factory;


/**
 * A short teaser of what Lookup does.
 *
 * More lengthy description of what Lookup does and why it's fantastic.
 *
 * <h3>Usage Examples</h3>
 *
 *
 * @todo Write documentation for Lookup
 * <h4>Example 1</h4>
 * <p>Description 1</p>
 * <code>
 * // Some code for example 1
 * $a = $b;
 * </code>
 *
 *
 * <h4>Example 2</h4>
 * <p>Description 2</p>
 * <code>
 * // Some code for example 2
 * $b = $a;
 * </code>
 *
 * 
 * @package geocode
 * @author Charlie Powell <charlie@evalagency.com>
 *
 */
class Result {
	
	/**
	 * @var string|null 2-digit continent code
	 */
	public $continent;
	
	/**
	 * @var string|null 2-digit country code
	 */
	public $country;
	
	/**
	 * @var string|null Province/state code
	 */
	public $province;
	
	/**
	 * @var string|null City full name or NULL if not set
	 */
	public $city;
	
	/**
	 * @var string|null Timezone
	 */
	public $timezone;
	/**
	 * @var string|null Postal code
	 */
	public $postal;
	
	/**
	 * @var int Latitude
	 */
	public $lat;
	
	/**
	 * @var int Longitude
	 */
	public $lng;
	
	/**
	 * @var array Raw matched results passed in to create this result
	 */
	public $raw;

	public function __construct(array $row) {
		$this->raw = $row;
		
		foreach(
			[ 'continent', 'country', 'province', 'city', 'postal', 'lat', 'lng', 'timezone' ] as $key
		){
			if(isset($row[ $key ])){
				$this->$key = $row[ $key ];
			}
		}
	}

	public function getCountryName() : string {
		return t('STRING_COUNTRY_' . $this->country);
	}

	public function getCountryIcon($dimensions = '20x20') : string {
		if(!$this->country) {
			$f = Factory::File('assets/images/placeholders/generic.png');
		}
		else {
			$f = Factory::File('assets/images/iso-country-flags/' . strtolower($this->country) . '.png');
		}

		return $f->getPreviewURL($dimensions);
	}
	
	public function getContinentName() : string {
		return t('STRING_CONTINENT_' . $this->continent);
	}
	
	public function getProvinceName() : string {
		return t('STRING_PROVINCE_' . $this->country . '_' . $this->province);
	}
	
	public function getAsHTML($getflag){
		if($this->city == 'LOCAL'){
			$country = 'LOCAL';
			$cname = 'Local/Internal Connection';
			$flag = 'assets/images/iso-country-flags/intl.png';
			$check = false;
		}
		else{
			$country = $this->country;
			$cname = $this->getCountryName();
			$flag = 'assets/images/iso-country-flags/' . strtolower($this->country) . '.svg';
			$check = true;
		}

		if($getflag){
			$file = Factory::File($flag);

			if($file->exists()){
				$out = '<img width="20" height="20" src="' . $file->getURL() . '" title="' . $cname . '" alt="' . $country . '"/> ';
			}
			else{
				$out = '';
			}
		}
		else{
			$out = '';
		}


		if($check && $this->province && $this->city){
			$out .= $this->city . ', ' . $this->province;	
		}
		elseif($check && $this->province){
			$out .= $this->province;
		}
		elseif($check && $this->city){
			$out .= $this->city;
		}
		elseif($country){
			$out .= $country;
		}

		return $out;
	}
}
