{css src="assets/css/mediamanager/file_editor_block.css"}{/css}
{script library="jqueryui"}{/script}
{script library="notify"}{/script}

<div class="width-wrapper">
	<h1>Template Block Editor</h1>


	<div class="block-editor-interface {if !count($panels)}no-layout-selected{else}layout-selected{/if}">
		<h2 class="block-editor-layouts-header">Available Layouts</h2>

		<p class="message-tutorial block-editor-layouts-help">
			Select the layout for this page
		</p>

		<ul class="block-layouts tile-container" id="block-editor-layouts">

		</ul>

		<h2 class="block-editor-panels-header">Layout Block Regions</h2>

		<p class="message-tutorial block-editor-panels-help">
			Drag available blocks from the left into the requested columns for this page template.<br/><br/>
			You can rearrange existing blocks on the page too by dragging them.
		</p>

		<div class="block-editor">
			<div id="block-editor-available-blocks" class="block-editor-available-blocks">
				<div class="block-panel-title">Available Blocks</div>

				<div class="block-editor-panel-blocks tile-container" data-block-panel="__available_blocks_list">

				</div>

			</div>

			<div class="block-editor-panel-workspace">

			</div>
		</div>

		{$form->render()}

		<div class="block-editor-panels-actions">
			<div class="button-group">
				<a href="#" class="button back-script">
					<i class="icon icon-backward"></i>
					<span>Back to Template Selection</span>
				</a>
				<a href="#" class="button save-script">
					<i class="icon icon-check"></i>
					<span>Save Template</span>
				</a>
			</div>
		</div>

	</div>
</div>

{script location="foot"}<script>
	(() => {
		let panelID, panelBlocks, sortables,
			installedKeys = [],
			editorInterface = document.querySelector('.block-editor-interface'),
			editorForm = document.getElementById('block-editor-form'),
			availableLayouts = document.getElementById('block-editor-layouts'),
			availableBlocks = document.querySelector('[data-block-panel=__available_blocks_list]'),
			editorWorkspace = document.querySelector('.block-editor-panel-workspace');

		function clearPanels() {
			installedKeys = [];
			editorWorkspace.innerHTML = '';
		}

		function createLayout(layoutData) {
			let layout,
				layoutPanels = [],
				panelCount = 0,
				i;

			for(i in layoutData.panels) {
				if(layoutData.panels[i].key && layoutData.panels[i].name) {
					panelCount++;
					layoutPanels.push({
						key: layoutData.panels[i].key,
						name: layoutData.panels[i].name
					});
				}
			}

			layout = document.createElement('li');
			layout.key = layoutData.key;
			layout.templateContent = layoutData.templateContent;
			layout.panels = layoutPanels;
			layout.innerHTML = '<div class="tile-title">' + layoutData.name + '</div><div class="tile-description">Contains ' + panelCount + ' panels</div>';
			layout.classList.add('tile', 'selectable');

			availableLayouts.appendChild(layout);
		}

		function createBlock(blockData) {
			let block, innerHTML, target;

			block = document.createElement('div');
			block.classList.add('block', 'tile', 'selectable');
			innerHTML = '<span class="tile-title">' + blockData.name + '</span>';
			block.name = blockData.name;
			block.templateContent = blockData.templateContent;
			block.single = blockData.single;
			block.key = blockData.key;
			block.image = blockData.image;

			if(block.image) {
				innerHTML += '<div class="tile-image"><img src="' + block.image + '" title="' + blockData.name + '"/></div>';
			}

			innerHTML += '<a href="#" class="edit-block-link" title="Edit HTML"><i class="icon icon-edit"></i></a>';

			if(blockData.panel) {
				target = editorWorkspace.querySelector('[data-block-panel="' + blockData.panel + '"]');

				if(blockData.key) {
					installedKeys.push(blockData.key);
				}
			}
			else {
				target = availableBlocks;
			}

			block.innerHTML = innerHTML;

			target.appendChild(block);
		}

		function installBlock(blockData) {
			if(blockData.key) {
				if(blockData.single === '1' || blockData.single === 1) {
					// This block can only be on the page once, make sure it's not already loaded.
					if(installedKeys.indexOf(blockData.key) !== -1) {
						$.notify('This element can only be loaded once on the page!', 'error');
						return;
					}
				}
				else {
					// This block has a key associated with it, ensure it's unique so multiple of these entries can be added.
					let newKey = blockData.key.toLowerCase() + Math.floor(Math.random()*10000),
						rg = new RegExp(blockData.key, 'g');

					// Swap the content of this key with the newly generated key
					blockData.templateContent = blockData.templateContent.replace(rg, newKey);
					blockData.key = newKey;
				}
			}

			createBlock(blockData);
			$.notify('Installed block ' + blockData.name + ' into ' + blockData.panel, 'success');
		}

		function rebuildSortables() {
			if(sortables) {
				// Cleanup first.
				sortables.sortable('destroy');
			}

			sortables = $('[data-block-panel]');
			sortables.addClass('tile-container');
			sortables.sortable({
				start: function(event, ui) {
					item = ui.item;
					newList = oldList = ui.item.closest('[data-block-panel]');
				},
				stop: function(event, ui) {
					let toAvailable = newList.data('block-panel') === '__available_blocks_list',
						fromAvailable = oldList.data('block-panel') === '__available_blocks_list';

					if(toAvailable && fromAvailable) {
						$.notify('Rearranging the available list has no affect.', 'warning');
						return false;
					}
					else if(oldList === newList) {
						$.notify('Respositioned block ' + item.text(), 'success');
					}
					else if(toAvailable) {
						if(item[0].key && installedKeys.indexOf(item[0].key) !== -1) {
							// Remove this from the list of registered keys
							installedKeys.splice(installedKeys.indexOf(item[0].key), 1);
						}
						item.remove();
						$.notify('Removed block ' + item.text() + ' from page template', 'success');
					}
					else if(fromAvailable) {
						// This is a new block installation!
						// Format the newly created block to be formatted correctly so it
						// doesn't conflict with other elements on the rendered template.
						installBlock({
							name: item[0].name,
							templateContent: item[0].templateContent,
							panel: newList.data('block-panel'),
							key: item[0].key,
							single: item[0].single,
							image: item[0].image
						});
						return false;
					}
					else {
						$.notify('Moved block ' + item.text() + ' to ' + newList.data('block-panel'), 'success');
					}
				},
				change: function(event, ui) {
					if(ui.sender) {
						newList = ui.placeholder.closest('[data-block-panel]');
					}
				},
				connectWith: '[data-block-panel]'
			}).disableSelection();
		}

        {foreach $layouts as $layout}
			createLayout({$layout|json_encode});
			{if $layout.current}
				let html = {$layout|json_encode}.templateContent;
				{literal}
					// Strip out smarty content.
					html = html.replace(/\{[^\}]*\}/g, '');
				{/literal}
				editorWorkspace.innerHTML = html;
			{/if}
        {/foreach}

        {foreach $blocks as $block}
			createBlock({$block|json_encode});
        {/foreach}

		rebuildSortables();


		availableLayouts.querySelectorAll('.tile').forEach(el => {
			el.addEventListener('click', evt => {
				evt.preventDefault();

				let tile = evt.target.closest('.tile'),
					i,
					html,
					editorWorkspace = document.querySelector('.block-editor-panel-workspace');

				clearPanels();
				document.getElementById('formtextareainput-layout').value = tile.templateContent;

				html = tile.templateContent;
                {literal}
					// Strip out smarty content.
					html = html.replace(/\{[^\}]*\}/g, '');
                {/literal}
				editorWorkspace.innerHTML = html;

				editorInterface.classList.remove('no-layout-selected');
				editorInterface.classList.add('layout-selected');
				rebuildSortables();
			});
		});


		document.querySelector('.back-script').addEventListener('click', evt => {
			evt.preventDefault();
			editorInterface.classList.add('no-layout-selected');
			editorInterface.classList.remove('layout-selected');
		});

		document.querySelector('.save-script').addEventListener('click', evt => {
			evt.preventDefault();

			let blockCounts = 0;

			if(!document.getElementById('formtextareainput-layout').value) {
				alert('You must select a layout first.');
				return;
			}

			editorWorkspace.querySelectorAll('[data-block-panel]').forEach(panel => {
				let panelID = panel.dataset.blockPanel, html = '', input;

				panel.querySelectorAll('.block').forEach(block => {
					blockCounts++;
					input = document.createElement('textarea');
					input.name = 'panels[' + panelID + '][]';
					input.value = block.templateContent;
					input.style.display = 'none';
					editorForm.appendChild(input);

					// HTML is now used for testing.
					html += block.templateContent + "\n\n";
				});

				//console.log(panelID); console.log(html);
			});

			if(!blockCounts) {
				alert('No blocks have been added, please add something first.');
				return;
			}

			editorForm.submit();

		});

		document.querySelector('.block-editor').addEventListener('click', evt => {
			if(evt.target.closest('.edit-block-link')) {
				let dialog = new Core.ModalDialog(),
					block = evt.target.closest('.block'),
					blockEditorTextarea;
				dialog.open();

				dialog.frame.innerHTML = '<textarea id="block-editor-block-edit" rows="10"></textarea><a href="#" class="button" id="block-editor-block-save"><span>Save Block</span></a>';

				blockEditorTextarea = document.getElementById('block-editor-block-edit');
				blockEditorTextarea.value = block.templateContent;

				document.getElementById('block-editor-block-save').addEventListener('click', evt => {
					block.templateContent = blockEditorTextarea.value;
					dialog.close();
					$.notify('Updated block content', 'success');
					evt.preventDefault();
				});

				evt.preventDefault();
			}
		});
	})();

</script>{/script}