Core.MarkdownEditor = class {
	constructor(element) {
		this.textarea = element;
		this.textarea.editorLoaded = true;

		let controls = element.closest('.form-element-value').querySelector('.toolbar');

		controls.querySelector('.do-bold').addEventListener('click', evt => {
			this.doBold();
			evt.preventDefault();
		});
		controls.querySelector('.do-italic').addEventListener('click', evt => {
			this.doItalic();
			evt.preventDefault();
		});
		controls.querySelector('.do-strikethrough').addEventListener('click', evt => {
			this.doStrikethrough();
			evt.preventDefault();
		});
		controls.querySelector('.do-ul').addEventListener('click', evt => {
			this.doUL();
			evt.preventDefault();
		});
		controls.querySelector('.do-ol').addEventListener('click', evt => {
			this.doOL();
			evt.preventDefault();
		});
		controls.querySelector('.do-link').addEventListener('click', evt => {
			this.doLink();
			evt.preventDefault();
		});
		controls.querySelector('.do-image').addEventListener('click', evt => {
			this.doImage();
			evt.preventDefault();
		});
	}

	hasSelection() {
		return this.textarea.selectionStart !== this.textarea.selectionEnd;
	}

	doBold() {
		this.simpleInsert('**%**');
	}

	doItalic() {
		this.simpleInsert('_%_');
	}

	doStrikethrough() {
		this.simpleInsert('~~%~~');
	}

	doUL() {
		this.blockInsert("* %\n* \n* ");
	}

	doOL() {
		this.blockInsert("1. %\n2. \n3. ");
	}

	doImage() {
		this.simpleInsert('![%]()');
	}

	doLink() {
		if(this.hasSelection()) {
			this.simpleInsert('[%](^)');
		}
		else {
			this.simpleInsert('[%]()');
		}
	}

	simpleInsert(text) {
		let start = this.textarea.selectionStart,
			end = this.textarea.selectionEnd,
			cpos,
			value = this.textarea.value;

		if(text.indexOf('^') === -1) {
			cpos = text.indexOf('%');
		}
		else {
			cpos = text.indexOf('^');
			if(cpos > text.indexOf('%')) {
				// The cursor position is after the text replacement position; this will get shifted.
				cpos--;
			}

			text = text.replace('^', '');
		}

		if(start === end) {
			// Append to the end
			if(value === '') {
				this.textarea.value = text.replace('%', '');
			}
			else {
				let lastCharacter = value.substr(value.length - 1);
				if(lastCharacter === ' ' || lastCharacter === "\n") {
					this.textarea.value = value + text.replace('%', '');
					cpos += value.length;
				}
				else {
					this.textarea.value = value + " " + text.replace('%', '');
					cpos += 1 + value.length;
				}
			}
		}
		else {
			// Replace linked text
			let preText = value.substr(0, start),
				postText = value.substr(end),
				innerText = value.substr(start, end - start);

			this.textarea.value = preText + text.replace('%', innerText) + postText;
			cpos += preText.length + innerText.length;
		}

		this.textarea.focus();
		this.textarea.selectionStart = cpos;
		this.textarea.selectionEnd = cpos;
	}

	blockInsert(text) {
		let start = this.textarea.selectionStart,
			end = this.textarea.selectionEnd,
			cpos,
			value = this.textarea.value;

		if(text.indexOf('^') === -1) {
			cpos = text.indexOf('%');
		}
		else {
			cpos = text.indexOf('^');
			if(cpos > text.indexOf('%')) {
				// The cursor position is after the text replacement position; this will get shifted.
				cpos--;
			}

			text = text.replace('^', '');
		}

		if(start === end) {
			// Append to the end
			if(value === '') {
				this.textarea.value = text.replace('%', '');
			}
			else {
				this.textarea.value = value + "\n\n" + text.replace('%', '');
				cpos += 2 + value.length;
			}
		}
		else {
			// Replace linked text
			let preText = value.substr(0, start),
				postText = value.substr(end),
				innerText = value.substr(start, end - start);

			this.textarea.value = preText + text.replace('%', innerText) + postText;
			cpos += preText.length + innerText.length;
		}

		this.textarea.focus();
		this.textarea.selectionStart = cpos;
		this.textarea.selectionEnd = cpos;
	}
}
