<?php
/**
 * Core bootstrap file that kicks off the entire application
 *
 * This file is the core of the application; it's responsible for setting up
 *  all the necessary paths, settings and includes.
 *
 * @package Core
 * @since 0.1
 * @author Charlie Powell <charlie@evalagency.com>
 * @copyright Copyright (C) 2009-2017  Charlie Powell
 * @license GNU Affero General Public License v3 <http://www.gnu.org/licenses/agpl-3.0.txt>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/agpl-3.0.txt.
 */


/********************* Pre-instantiation system checks ************************/

if (PHP_VERSION < '7.0.0') {
	die('Please install PHP 7.0 or greater to run this application.  For a howto, you may refer to https://portal.eval.bz/tech-guides/install-php-on-linux');
}

define('CORE_START_MICROTIME', microtime(true));

// Damn suPHP, I can handle my own permissions, TYVM
umask(0);

if(function_exists('mb_internal_encoding')){
	// gogo i18n!
	mb_internal_encoding('UTF-8');
}

// Allow the calling script to set a FULL_TRACE option for Core development.
// This sets all error reporting and logging to max.
// Otherwise, disable all error reporting by default until the framework loads
// and can better handle errors.
if(defined('FULL_TRACE') && FULL_TRACE){
	error_reporting(E_ALL | E_STRICT);
	ini_set('display_errors', 1);
	ini_set('html_errors', 1);
}
else{
	ini_set('display_errors', 0);
	ini_set('html_errors', 0);
}

/********************* Initial system defines *********************************/
require_once 'bootstrap_predefines.php';

require_once __DIR__ . '/libs/core/utilities/profiler/Profiler.php';
require_once __DIR__ . '/libs/core/utilities/profiler/ProfilerEvent.php';
\Core\Utilities\Profiler\Profiler::GetDefaultProfiler();

/********************** Critical file inclusions ******************************/
require_once 'bootstrap_preincludes.php';

// And start the core!
\Core\Core::Start();
