<?php

use Core\Controller;

class GettingStartedController extends Controller {
	/**
	 * Display an option to create the first user or state that a user account has been created.
	 *
	 * @throws \Core\AccessDeniedException
	 */
	public function user() {
		$view = $this->getView();

		$usersExist = (UserModel::Count() !== 0);
		$userIsAdmin = \Core\user()->checkAccess('g:admin');

		if($usersExist && !$userIsAdmin) {
			throw new \Core\AccessDeniedException();
		}

		$view->title = 'Quick Start - Create Account';
		$view->ssl = true;
		$view->addMetaName('robots', 'noindex');
		$view->assign('users_exist', $usersExist);
	}

	/**
	 * Display overview information about components, just that there are some to install
	 *
	 * @core-access-string g:admin
	 */
	public function components() {
		$view = $this->getView();
		$request = $this->getRequest();

		$componentsInstalled = \Core\Core::GetComponents();
		$componentsAvailable = \Core\Core::GetDisabledComponents();

		if($request->isPost() && $request->getParameter('install')) {
			// Attempt a dummy install of everything.
			$changes = [];
			$errors = [];

			foreach($componentsAvailable as $component) {
				/** @var \Core\Component $component */
				$ret = $component->install();
				$changes = array_merge($changes, $ret['changes']);
				$errors = array_merge($errors, $ret['errors']);
			}
		}
		else {
			$changes = null;
			$errors = null;
		}

		$view->title = 'Quick Start - Components';
		$view->ssl = true;
		$view->addMetaName('robots', 'noindex');
		$view->assign('components_installed', $componentsInstalled);
		$view->assign('components_available', $componentsAvailable);
		$view->assign('changes', $changes);
		$view->assign('errors', $errors);
	}

	/**
	 * Display overview options to configure the site, powered by components
	 *
	 * @core-access-string g:admin
	 */
	public function configure() {
		$view = $this->getView();
		$request = $this->getRequest();

		$links = \Core\HookHandler::DispatchHook('/core/gettingstarted/configurelinks');

		$view->title = 'Quick Start - Configure';
		$view->ssl = true;
		$view->addMetaName('robots', 'noindex');
		$view->assign('links', $links);
	}
}