<?php
/**
 * File for class PageController definition in the coreplus project
 * 
 * @author Charlie Powell <charlie@evalagency.com>
 * @date 20140314.1632
 * @copyright Copyright (C) 2009-2017  Charlie Powell
 * @license GNU Affero General Public License v3 <http://www.gnu.org/licenses/agpl-3.0.txt>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/agpl-3.0.txt.
 */

use Core\BaseURLMap;
use Core\Core;
use Core\Controller;
use Core\Datamodel\DatasetStream;
use Core\Forms\Form;
use Core\HookHandler;
use Core\ModelFactory;
use Core\Search\ModelResult;
use Core\Search\SearchResults;
use Core\View;
use Core\Router;
use Core\Session;
use Core\AccessDeniedException;


/**
 * A short teaser of what PageController does.
 *
 * More lengthy description of what PageController does and why it's fantastic.
 *
 * <h3>Usage Examples</h3>
 *
 *
 * @todo Write documentation for PageController
 * <h4>Example 1</h4>
 * <p>Description 1</p>
 * <code>
 * // Some code for example 1
 * $a = $b;
 * </code>
 *
 *
 * <h4>Example 2</h4>
 * <p>Description 2</p>
 * <code>
 * // Some code for example 2
 * $b = $a;
 * </code>
 *
 * 
 * @author Charlie Powell <charlie@evalagency.com>
 *
 */
class PageController extends Controller {

	public function password() {
		$view = $this->getView();
		$request = $this->getRequest();

		// Grab the original page Model from the requested page.
		$original = new BaseURLMap($request->uriBase);
		$page = $original->getPageModel();

		\Core\set_message('t:MESSAGE_INFO_ENTER_PASSWORD_TO_VIEW_PAGE');

		$view->title = 't:STRING_PASSWORD_PROTECTED_PAGE';
		$view->templatename = 'page/passwordprotected.tpl';
		$view->allowerrors = true;
		$view->status = View::STATUS_ACCESSDENIED;

		$form = new Form();

		$form->set('callsmethod', 'PageController::PasswordSubmit');
		$form->addElement(
			'system', [
				'name'  => 'page',
				'value' => $page,
			]
		);

		$form->addElement(
			'password', [
				'name'      => 'passinput',
				'title'     => 'Password',
				'required'  => 'required',
				'maxlength' => 128
			]
		);
		$form->addElement(
			'submit', [
				'value' => 't:STRING_CONTINUE'
			]
		);

		$view->assign('form', $form);
	}

	public function search(){
		$view     = $this->getView();
		$request  = $this->getRequest();

		if(!$request->getParameter('q')){
			// Simply redirect to the sitemap if no query was provided.
			throw new \Core\RedirectException('/page/sitemap');
		}

		$results = HookHandler::DispatchHook('/core/page/search', $request->getParameter('q'));

		//HookHandler::DispatchHook('/core/page/search/results', $search);

		$view->title = 'Site Search';
		$view->assign('query', $request->getParameter('q'));
		$view->assign('pages', $results);
	}

	public function sitemap(){
		$view  = $this->getView();
		$req   = $this->getRequest();

		// Give me every registered (public) page!
		$factory = new ModelFactory('PageModel');
		$factory->where('indexable = 1');
		$factory->order('title');
		// Multisite?
		if(Core::IsComponentAvailable('multisite') && MultiSiteHelper::IsEnabled()){
			$factory->whereGroup(
				'OR',
				array(
					'site = ' . MultiSiteHelper::GetCurrentSiteID(),
					'site = -1'
				)
			);
			$site = MultiSiteHelper::GetCurrentSiteID();
		}
		else{
			$site = null;
		}

		$user = \Core\user();
		$toshow = array();
		foreach($factory->generator() as $record) {
			/** @var PageModel $record */

			if(!$user->checkAccess( $record->access )){
				// Skip any further operations if the user does not have access to this page
				continue;
			}

			if(!$record->isPublished()) {
				// Skip any further operations if the page isn't even marked as published.
				continue;
			}
			
			if(!Core::IsComponentAvailable( $record->component )){
				// Skip any page where the registered component is not enabled or available.
				// this can happen if the admin disables a component without uninstalling it.
				continue;
			}

			$toshow[] = $record;
		}

		// Anything else?
		$extra = HookHandler::DispatchHook('/sitemap/getlisting');
		$toshow = array_merge($toshow, $extra);

		// This page allows for a few content types.
		switch($req->ctype){
			case View::CTYPE_XML:
				$view->contenttype = View::CTYPE_XML;
				$view->templatename = 'pages/page/sitemap_xml';
				$view->mastertemplate = false;
				break;
			case View::CTYPE_HTML:
			default:
				$view->contenttype = View::CTYPE_HTML;
				break;
		}
		
		$view->title = 'Sitemap';
		$view->assign('pages', $toshow);
		$view->assign('site', $site);
	}

	/**
	 * Resolve a URL baseurl or rewriteurl to its fully resolved URL
	 *
	 * @param string $q
	 */
	public function url(string $q) {
		$view = $this->getView();
		$view->mode = View::MODE_AJAX;
		$view->contenttype = View::CTYPE_JSON;

		$view->appendJSONDataKey('url', \Core\resolve_link($q));
	}
	
	public static function PasswordCheck() {
		
		$page = Router::$DefaultPageModel;
		
		// If the page isn't defined, then no password can be set.
		if(!$page){
			return true;
		}
		
		if(
			$page->get('password_protected') &&
			Session::Get('page-password-protected' . $page->get('baseurl')) !== $page->get('password_protected')
		) {

			// Change the base URL to the page system password page instead.
			// This will prevent the default Controller from being called!
			Router::ChangeBaseURL('/page/password');
			return true;
		}
	}
	
	public static function PasswordSubmit(Form $form){
		/** @var PageModel $page */
		$page = $form->getElementValue('page');
		$val  = $form->getElementValue('passinput');
		if( $val !== $page->get('password_protected') ){
			\Core\set_message('t:MESSAGE_ERROR_INCORRECT_PASSWORD');
			return false;
		}
		else {
			\Core\Session::Set('page-password-protected' . $page->get('baseurl'), $val);
			return $page->get('baseurl');
		}
	}
} 
