<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

namespace Core;

use Exception;
use JQuery\Loader as jQUeryLoader;

/**
 * Description of CoreJSLoader
 *
 * @author charlie
 */
class CoreJSLoader {
	private static $_LoadedCore = false;

	public static function GetCoreScriptData() : array {
		try {
			$user = \Core\user();
			$userid = $user->id;
			$userauth = $user->checkExists();
		}
		catch(Exception $ex) {
			$userid = 0;
			$userauth = false;
		}

		$ua = \Core\UserAgent::Construct();

		$url = htmlentities(Router::$DefaultBaseURL->getRewriteURL());

		$rootWDIR     = ROOT_WDIR;
		$rootURL      = ROOT_URL;
		$rootURLSSL   = ROOT_URL_SSL;
		$rootURLnoSSL = ROOT_URL_NOSSL;
		$ssl          = SSL ? 'true' : 'false';
		$sslMode      = SSL_MODE;

		$data = [
			'ROOT_WDIR' => $rootWDIR,
			'ROOT_URL' => $rootURL,
			'ROOT_URL_SSL' => $rootURLSSL,
			'ROOT_URL_NOSSL' => $rootURLnoSSL,
			'SSL' => $ssl,
			'SSL_MODE' => $sslMode,
			'User' => [
				'id' => $userid,
				'authenticated' => $userauth,
			],
			'Url' => $url,
			'Browser' => $ua->asArray(),
		];

		return $data;
	}

	/**
	 * Function that attaches the core javascript to the page.
	 *
	 * This should be called automatically from the hook /core/page/preexecute.
	 */
	public static function AttachCoreJavascript(View $view) {
		
		// This requires Core to be installed.
		if(!Core::IsInstalled()) {
			return true;
		}

		if($view->mode !== View::MODE_PAGE) {
			return true;
		}

		// And the static functions.
		self::AttachCoreJS();
	}

	public static function AttachCoreJS() {
		// Include the base Core object if not already provided
		if(!self::$_LoadedCore) {
			$data = self::GetCoreScriptData();
			$script = '<script type="text/javascript">let Core = window.Core || ' . json_encode($data) . ';</script>';
			Router::$DefaultView->addScript($script, 'head');
		}

		Router::$DefaultView->addScript('js/core.head.js', 'head');

		// @todo Finish phasing out the requirement for jQuery.
		jQUeryLoader::IncludeJQuery();

		Router::$DefaultView->addScript('js/core.js', 'foot');

		return true;
	}

	/**
	 * Add the Core.Strings library to the page
	 *
	 * @return bool
	 */
	public static function AttachCoreStrings() {
		return self::AttachCoreJS();
	}

	/**
	 * Add the Core.Ajaxlinks library to the page
	 *
	 * @return bool
	 */
	public static function AttachAjaxLinks(){
		\JQuery\Loader::IncludeJQueryUI();
		Router::$DefaultView->addScript('js/core.ajaxlinks.js', 'foot');

		return true;
	}

	/**
	 * Add the LESS library to the page
	 *
	 * @return bool
	 */
	public static function AttachLessJS(){
		Router::$DefaultView->addScript('js/less-1.7.1.js', 'head');

		return true;
	}

	public static function AttachJSON(){
		Router::$DefaultView->addScript ('js/json2.js', 'head');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}
	
	public static function AttachCookie() {
		Router::$DefaultView->addScript ('js/js.cookie.js', 'head');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}
	
	public static function AttachNotify() {
		\JQuery\Loader::IncludeJQuery();
		
		Router::$DefaultView->addScript ('js/notify.js', 'head');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}
}
