<?php
/**
 * Standard Data Model Interface exceptions used by the DMI system
 * 
 * @package Core\Datamodel
 * @since 7.0.0
 * @author Charlie Powell <charlie@evalagency.com>
 * @copyright Copyright (C) 2009-2018  Charlie Powell
 * @license GNU Affero General Public License v3 <http://www.gnu.org/licenses/agpl-3.0.txt>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/agpl-3.0.txt.
 */


namespace Core\Datamodel;

use Exception;


class DMIException extends Exception{
	const ERRNO_NODATASET = '42S02';
	const ERRNO_UNKNOWN = '07000';
	
	public $ansicode;
	
	public function __construct($message, $code = null, $previous = null, $ansicode = null) {
		parent::__construct($message, $code, $previous);
		
		if($ansicode) $this->ansicode = $ansicode;
		elseif($code) $this->ansicode = $code;
	}
}

class DMIBackendNotAvailableException extends DMIException {
	
}

class DMIServerNotFoundException extends DMIException {
	
}

class DMIAuthenticationFailedException extends DMIException {
	
}

class DMIDatabaseDoesNotExistException extends DMIException {
	
}

class DMITableDoesNotExistException extends DMIException {
	
}

class DMIQueryException extends DMIException{
	/**
	 * The query that caused the exception.
	 * @var string
	 */
	public $query = null;
}

class DMIUnknownColumnException extends DMIQueryException {
	
}
