<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

namespace Core\Datamodel;

use Core\ConfigHandler;
use Core\Logger\LogSinkInterface;
use Core\Logger\LogEntry;

/**
 * Description of DatabaseLogSink
 *
 * @author charlie
 */
class DatabaseLogSink implements LogSinkInterface {
	
	public function getDefaultLevel(): int {
		// Until the database is ready, this is 0 as the database will not be available.
		return 0;
		/*
		$level = ConfigHandler::Get('/core/logs/db/level');
		
		return (int)$level;*/
	}

	public function getMaximumLevel(): int {
		return 3; // Only INFO and above is allowed
	}

	public function log(LogEntry $entry) {
		$log = \SystemLogModel::Factory();
		$details = $entry->details;

		$log->setFromArray([
			// Log information
			'type'             => $entry->type,
			'level'            => $entry->level,
			'code'             => $entry->code,
			'message'          => $entry->message,
			'affected_user_id' => $entry->user,
			'source'           => $entry->source,
			'icon'             => $entry->icon,
			// Environmental information
			'session_id'       => session_id(),
			'user_id'          => (\Core\user() ? \Core\user()->get('id') : 0),
			'url'              => $_SERVER['REQUEST_URI'] ?? '',
			'referrer'         => $_SERVER['HTTP_REFERER'] ?? '',
			'ip_addr'          => (defined('REMOTE_IP') && REMOTE_IP) ? REMOTE_IP : '::1',
			'useragent'        => $_SERVER['HTTP_USER_AGENT'] ?? '',
		]);

		if($entry->tags) {
			$details .= "\n\nTags:";
			foreach($entry->tags as $tag => $val) {
				$details .= "\n" . $tag . ': ' . $val;
			}
		}

		if($entry->trace) {
			$details .= "\n\nStack Trace:";
			foreach($entry->trace as $line) {
				$details .= "\n" . $line['formatted'];
			}
		}


		$log->details = $details;

		$log->save();
	}
}
