<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

namespace Core\EmailAPI;

use Core\Filestore\FileHelper;
use Core\Filestore\Factory as FileFactory;

/**
 * Description of EmailAttachment
 *
 * @author charlie
 */
class EmailAttachment {
	
	public $filepath;
	public $filename;
	public $contents;
	public $encoding;
	public $mimetype;
	public $disposition;
	
	/**
	 * Get the icon URL for this attachment based on its mimetype
	 * 
	 * @param string $dimensions Dimensions to request, (has no effect if icon is SVG)
	 * 
	 * @return string Fully resolved URL
	 */
	public function getIcon(string $dimensions = '32x32') : string {
		return FileHelper::GetIconFileForMimetype($this->mimetype)->getPreviewURL($dimensions);
	}
	
	public function getFilesize(string $format = 'text/html') : string {
		if($this->filepath) {
			$size = FileFactory::File($this->filepath)->getFilesize();
		}
		elseif($this->filename && $this->contents) {
			$size = strlen($this->contents);
		}
		else {
			$size = 0;
		}
		
		return $format === 'text/html' ? FileHelper::FormatSize($size) : (string)$size;
	}
	
	/**
	 * Send this attachment to the user agent; useful for previewing before sending.
	 */
	public function sendToUserAgent() {
		if($this->filepath) {
			$file = FileFactory::File($this->filepath);
			$file->sendToUserAgent(false);
		}
		elseif($this->filename && $this->contents) {
			$file = FileFactory::File('tmp/emailattachment-' . \Core\random_hex(4) . '/' . $this->filename);
			$file->putContents($this->contents);
			$file->sendToUserAgent(false);
			
			$file->delete();
		}
	}
}
