<?php
/**
 * Class file for FormCheckboxInput
 *
 * @package Core\Forms
 * @author Charlie Powell <charlie@evalagency.com>
 * @copyright Copyright (C) 2009-2017  Charlie Powell
 * @license GNU Affero General Public License v3 <http://www.gnu.org/licenses/agpl-3.0.txt>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/agpl-3.0.txt.
 */

namespace Core\Forms;

/**
 * Class FormCheckboxInput provides a single checkbox with one value that's either checked or not.
 *
 * @package Core\Forms
 */
class CheckboxInput extends FormElement {
	public function  __construct($atts = null) {
		parent::__construct($atts);

		// Some defaults
		$this->_attributes['class'] = 'formelement formcheckboxinput';
		$this->_validattributes     = array('accesskey', 'checked', 'dir', 'disabled', 'id', 'lang', 'name', 'required', 'tabindex', 'style', 'value');
	}
	
	/**
	 * Template helper function
	 * Gets the input attributes as an associative array
	 * @return array
	 */
	public function getInputAttributesAsArray() : array {
		$atts = parent::getInputAttributesAsArray();
		
		// Single checkboxes always have their value set to "1".
		$atts['value'] = '1';
		
		return $atts;
	}
	
	public function getValue() {
		return $this->_attributes['checked'];
	}
	
	/**
	 * This set explicitly handles the value, and has the extended logic required
	 *  for error checking and validation.
	 *
	 * @param mixed $value The value to set
	 * @return boolean
	 */
	public function setValue($value) {
		// Whatever resolves true-ish will set checked to true as opposed to setting the actual value.
		$this->_attributes['checked'] = ($value === '1' || $value === 1 || $value === 'yes' || $value === 'on');

		return true;
	}

}