<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

namespace Core\Installer\Checks;

/**
 * Compound directory checks are rarely needed to be called explictly,
 * but rather are extended by Asset, Public, and Private directory checks.
 *
 * @author charlie
 */
abstract class CompoundDirectoryCheck implements CheckInterface {
	
	protected $_title;
	protected $_path;
	protected $_type;
	protected $_checks;
	
	public function __construct() {
		$this->_checks = [];
		
		$this->_checks[] = new WriteableDirectoryCheck($this->_path);
		$this->_checks[] = new DirectoryProtectionCheck($this->_path, $this->_type);
		$this->_checks[] = new DirectoryContentsWriteableCheck($this->_path);
	}
	
	public function getDetails(): string {
		return $this->_path . ' and its contents need to be writeable by the web server';
	}

	/**
	 * Get additional details about this check, but not necessarily about the fix.
	 * @return string
	 */
	public function getInformation() : string {
		return '';
	}

	public function getFix(): string {
		$fixes = '';
		
		foreach($this->_checks as $check){
			if(!$check->test()){
				$fixes .= $check->getFix() . NL;
			}
		}
		
		return $fixes;
	}

	public function getTitle(): string {
		return $this->_title;
	}

	public function test(): bool {
		foreach($this->_checks as $check){
			if(!$check->test()){
				return false;
			}
		}
		
		return true;
	}

}
