<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

namespace Core\Installer\Checks;
use Core\Installer\InstallHelper;

/**
 * Description of MemoryLimitCheck
 *
 * @author charlie
 */
class MemoryLimitCheck implements CheckInterface {
	/**
	 * Get the title of this check
	 * @return string
	 */
	public function getTitle() : string {
		return 'PHP Memory Limit';
	}
	
	/**
	 * Run the test for this check
	 * @return bool True if passed, False otherwise
	 */
	public function test() : bool {
		$limit = $this->_getLimit();

		return ($limit >= 64 * 1024 * 1024);
	}
	
	/**
	 * Get the fix for this problem that instructs the user how to fix it
	 * @return string
	 */
	public function getDetails(): string {
		$ini = $this->_getINIFile();
		$limit = $this->_getLimit();

		if($this->test()) {
			return \Core\Filestore\FileHelper::FormatSize($limit, 0) . ' memory limit as defined in ' .
				$ini . ' is sufficient to run Core Plus, (requires 64MB)';
		}
		else {
			return 'Edit ' . $ini . ' and set the "memory_limit" directive to 64M';
		}
	}
	
	/**
	 * Get the scripted fix for this problem that provides the user how to fix it
	 * @return string
	 */
	public function getFix() : string {
		$ini = $this->_getINIFile();
		
		return "sed -i 's:^memory_limit = .*:memory_limit = 64M:g' " . escapeshellarg($ini);
	}

	private function _getINIFile() : string {
		if(EXEC_MODE === 'WEB') {
			return php_ini_loaded_file();
		}
		elseif(EXEC_MODE === 'CLI') {
			// Retrieve the file, but try to guess the apache location.
			// Worst case here, we just return the CLI version.
			$ini = php_ini_loaded_file();
			$apacheIni = str_replace('/cli/', '/apache2/', $ini);

			if(file_exists($apacheIni)) {
				return $apacheIni;
			}
			else {
				return $ini;
			}
		}
		else{
			// @todo
			return '';
		}
	}

	private function _getLimit() : int {
		if(EXEC_MODE === 'WEB'){
			$mlimit = ini_get('memory_limit');
		}
		else{
			// When running on the CLI, we need to do some hackery to get the web's memory limit.
			if(($file = $this->_getINIFile()) === ''){
				// ummmmm
				return 256;
			}

			$mlimit = array_map(
				'trim',
				explode(
					'=',
					trim(
						exec("egrep '^memory_limit' " . escapeshellarg($file))
					)
				)
			)[1];
		}

		// A size of -1 means no limit, but since we're expecting an actual number, we'll return something high.
		if($mlimit == '-1') {
			$munits = 'G';
			$msize = 16;
		}
		else {
			$munits = substr($mlimit, -1);
			$msize  = substr($mlimit, 0, -1);
		}


		if($munits == 'G') {
			$msize = $msize * 1024 * 1024 * 1024;
		}
		elseif($munits == 'M') {
			$msize = $msize * 1024 * 1024;
		}
		elseif($munits == 'K') {
			$msize = $msize * 1024;
		}

		return (int)$msize;
	}
}
