<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

namespace Core\Installer\Checks;

use Core\Installer\InstallHelper;

/**
 * Description of PHPExtensionCheck
 *
 * @author charlie
 */
class PHPExtensionCheck {
	
	private $_extension;
	
	private static $_ProblematicExtensions = [
		'hash' => [
			'details' => 'Cryptographic hash capability requires PHP to be compiled without the "--disable-hash" flag!',
		],
		'zlib' => [
			'details' => 'ZLib compression and decompresion requies PHP to be compiled with the "--with-zlib" flag!',
		],
	];
	
	public function __construct(string $extension) {
		$this->_extension = $extension;
	}
	
	/**
	 * Get the title of this check
	 * @return string
	 */
	public function getTitle() : string {
		return 'PHP Extension ' . $this->_extension;
	}
	
	/**
	 * Run the test for this check
	 * @return bool True if passed, False otherwise
	 */
	public function test() : bool {
		
		$loaded = extension_loaded($this->_extension);
		
		if($loaded){
			return true;
		}
		elseif(EXEC_MODE === 'CLI' && ($fix = $this->getFix()) !== ''){
			// AUTO-INSTALL!
			$ret = null;
			$out = [];
			exec($fix, $out, $ret);
			return ($ret === 0);
		}
		else{
			return false;
		}
	}
	
	/**
	 * Get additional details that may help the user fix the problem
	 * @return string
	 */
	public function getDetails() : string {
		if($this->test()) {
			return $this->_extension . ' is available and is at version ' . phpversion($this->_extension);
		}
		else {
			if(
				isset(self::$_ProblematicExtensions[ $this->_extension ]) &&
				isset(self::$_ProblematicExtensions[ $this->_extension ]['details'])
			){
				return self::$_ProblematicExtensions[ $this->_extension ]['details'];
			}
			else{
				// Automatic support is supported!
				return 'Install the ' . $this->_extension . ' extension for PHP';
			}
		}
	}
	
	/**
	 * Get the scripted fix for this problem that provides the user how to fix it
	 * @return string
	 */
	public function getFix(): string {
		if(
			isset(self::$_ProblematicExtensions[ $this->_extension ])
		){
			return '';
		}
		
		$fixes = [];
		if($this->_extension === 'mysql'){
			// mysql has an additional requirement, but is otherwise auto-executable.
			if(trim(exec('which mysql')) === ''){
				$fixes[] = InstallHelper::GetPackageInstallCommand() . ' mariadb-client';
			}
		}

		$version = phpversion();
		// Trim the last minor version, we just need the release and major
		$version = substr($version, 0, strrpos($version, '.'));

		$fixes[] = InstallHelper::GetPackageInstallCommand() . ' php' . $version . '-' . $this->_extension;
		
		return implode(NL, $fixes);
	}
}
