<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

namespace Core\Installer\Checks;
use Core\Installer\InstallHelper;

/**
 * Description of MemoryLimitCheck
 *
 * @author charlie
 */
class WriteableFileCheck implements CheckInterface {
	private $_filename;
	
	public function __construct($filename){
		$this->_filename = $filename;
	}
	
	/**
	 * Get the title of this check
	 * @return string
	 */
	public function getTitle() : string {
		return basename($this->_filename) . ' writeable';
	}

	/**
	 * Get additional details about this check, but not necessarily about the fix.
	 * @return string
	 */
	public function getInformation() : string {
		return '';
	}
	
	/**
	 * Run the test for this check
	 * @return bool True if passed, False otherwise
	 */
	public function test() : bool {
		if(
			file_exists($this->_filename) && 
			is_writable($this->_filename)
		){
			return true;
		}
		elseif(
			is_dir(dirname($this->_filename)) && 
			is_writable(dirname($this->_filename))
		){
			return true;
		}
		elseif(
			is_dir(dirname(dirname($this->_filename))) && 
			is_writable(dirname(dirname($this->_filename)))
		){
			return true;
		}
		else{
			return false;
		}
	}
	
	/**
	 * Get additional details that may help the user fix the problem
	 * @return string
	 */
	public function getDetails() : string {
		$user = InstallHelper::GetUser();
		
		return 'Ensure that the user "' . $user . '" can create and write to the file ' . $this->_filename;
	}
	
	/**
	 * Get the fix for this problem that instructs the user how to fix it
	 * @return string
	 */
	public function getFix(): string {
		$user = InstallHelper::GetUser();
		
		if(file_exists($this->_filename) && !is_writable($this->_filename)){
			// File exists but just is not writeable.
			return 
				'sudo chown ' . $user . ':' . $user . ' ' . escapeshellarg($this->_filename) . NL .
				'sudo chmod 600 ' . escapeshellarg($this->_filename);
		}
		elseif(is_dir(dirname($this->_filename)) && !is_writable(dirname($this->_filename))){
			// Parent directory exists but is not writeable.
			return
				'sudo chown ' . $user . ':' . $user . ' ' . escapeshellarg(dirname($this->_filename)) . NL .
				'sudo chmod 600 ' . escapeshellarg(dirname($this->_filename));
		}
		else{
			// Parent directory doesn't exist
			return
				'sudo mkdir -p ' . escapeshellarg(dirname($this->_filename)) . NL .
				'sudo chown ' . $user . ':' . $user . ' ' . escapeshellarg(dirname($this->_filename)) . NL .
				'sudo chmod 600 ' . escapeshellarg(dirname($this->_filename));
		}
	}
}
