<?php


namespace Core\ListingTable;


use Generator;

interface TableInterface {

	/**
	 * Get all columns declared on this table
	 *
	 * @return Column[]
	 */
	public function getColumns() : array;

	/**
	 * Get all VISIBLE columns declared on this table
	 *
	 * @return Column[]
	 */
	public function getColumnsVisible() : array;

	/**
	 * Check if this table has bulk actions
	 *
	 * @return bool
	 */
	public function checkHasBulkActions() : bool;

	/**
	 * Get the current page being viewed
	 *
	 * @return int
	 */
	public function getPage() : int;

	/**
	 * Get the total number of records based on current filtering
	 *
	 * @return int
	 */
	public function getTotalCount() : int;

	/**
	 * Get the display limit, ie: number of results per page
	 *
	 * @return int
	 */
	public function getLimit() : int;

	/**
	 * Get all records *FOR THE CURRENT PAGE* on this table as a generator.
	 *
	 * If the backend supports pagination and limits, they will be applied here automatically.
	 *
	 * If you need to retrieve *ALL* records for the dataset,
	 * you will need to manually copy and manipulate the backend source
	 *
	 * @return Generator
	 */
	public function getRecords() : Generator;
}