<?php


namespace Core\Renderer;


class BadgeRenderer {
	/** @var string|null Optional string for retrieval purposes */
	public $key;
	/** @var string Title of the badge, displayed inline and as title attribute */
	public $title = '';
	/** @var string|null Optional icon to set, just the base icon name */
	public $icon;
	/** @var string|null Optional background color */
	public $color;
	/** @var array List of classes for this badge, recommended to keep badge base class, but can be removed. */
	public $classes = ['badge'];

	/**
	 * Fetch the resulting HTML for this image
	 */
	public function fetch() : string {
		$badgeAttributes = [
			'title' => $this->title,
			'class' => $this->classes
		];

		if($this->color) {
			// A color is assigned, set the necessary styles.
			$background = \Core\color_brightness_level($this->color) > 123 ? 'light-background' : 'dark-background';
			$badgeAttributes['classes'][] = $background;
			$badgeAttributes['styles'] = ['background-color' => $this->color];
		}

		$html = '<span ' . \Core\array_to_html_attributes_string($badgeAttributes) . '>';

		if($this->icon) {
			$html .= '<i class="icon icon-' . $this->icon . '"></i> ';
		}

		$html .= '<span>' . $this->title . '</span>';

		// Close the badge
		$html .= '</span>';

		return $html;
	}

	public function key(string $key) : self {
		$this->key = $key;
		return $this;
	}

	public function title(string $title) : self {
		$this->title = $title;
		return $this;
	}

	public function icon(string $icon) : self {
		$this->icon = $icon;
		return $this;
	}

	public function color(string $color) : self {
		$this->color = $color;
		return $this;
	}

	public function addClass(string $classname) : self {
		$this->classes[] = $classname;
		return $this;
	}

	public static function Factory() : self {
		return new BadgeRenderer();
	}
}