<?php
/**
 * jQuery library file, just includes the various jquery javascript assets.
 * 
 * @package Core
 * @since 6.3
 * @author Charlie Powell <charlie@evalagency.com>
 * @copyright Copyright (C) 2009-2017  Charlie Powell
 * @license GNU Affero General Public License v3 <http://www.gnu.org/licenses/agpl-3.0.txt>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/agpl-3.0.txt.
 */

namespace JQuery;
use Core\ConfigHandler;
use Core\Router;

abstract class Loader {
	
	public static function IncludeJQuery(){
		$use2x = ConfigHandler::Get('/jquery/use_2_x');

		if($use2x === 'auto'){
			// Determine if it should be used based on the UA.
			// Remember, only IE <= 8.0 requires this.
			$ua = \Core\UserAgent::Construct();
			if($ua->browser == 'IE' && $ua->version <= 8){
				$use2x = '0';
			}
			else{
				$use2x = '3';
			}
		}
		
		switch($use2x){
			case '0':
				// The admin requested not to use the new version of jQuery.  Stick with 1.11 then.
				Router::$DefaultView->addScript ('js/jquery/jquery-1.11.0.js');
				break;
			case '1':
			case '2':
				// The site is setup to use 2.x, (default as of Core 4.0).
				Router::$DefaultView->addScript ('js/jquery/jquery-2.1.4.js');
				break;
			case '3':
				// Core 6.2 started using jQuery 3.x
				Router::$DefaultView->addScript ('js/jquery/jquery-3.4.1.js');
				break;
		}
		
		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}
	
	public static function IncludeJQueryUI(){
		self::IncludeJQuery();
		Router::$DefaultView->addScript ('js/jquery/jquery-ui-1.12.1.js');
		Router::$DefaultView->addScript ('js/jquery/jquery.ui.touch-punch.js');
		
		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}
	
	public static function Include_nestedSortable(){
		// I need jquery ui first.
		self::IncludeJQueryUI();
		
		Router::$DefaultView->addScript ('js/jquery/jquery.ui.nestedSortable.js');
		
		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}

	public static function Include_tmpl(){
		// I need jquery ui first.
		self::IncludeJQueryUI();

		Router::$DefaultView->addScript ('js/jquery/tmpl.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}
	
	public static function Include_readonly(){
		// I need jquery ui first.
		self::IncludeJQueryUI();
		
		Router::$DefaultView->addStylesheet('css/jquery/jquery.readonly.css');
		Router::$DefaultView->addScript ('js/jquery/jquery.ui.readonly.js');
		
		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}
	
	public static function Include_json(){
		// I need jquery first.
		self::IncludeJQuery();
		
		Router::$DefaultView->addScript ('js/jquery/jquery.json-2.4.js');
		
		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}

	public static function Include_masonry(){
		// I need jquery first.
		self::IncludeJQuery();
		Router::$DefaultView->addScript('js/jquery/jquery.masonry.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}

	public static function Include_form(){
		// I need jquery first.
		self::IncludeJQuery();
		Router::$DefaultView->addScript('js/jquery/jquery.form.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}

	public static function Include_timepicker(){
		// I need jquery ui first.
		self::IncludeJQueryUI();
		Router::$DefaultView->addScript('js/jquery/jqueryui.timepicker.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}

	public static function Include_waypoints(){
		// I need jquery first.
		self::IncludeJQuery();
		Router::$DefaultView->addScript ('js/jquery/waypoints.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}

	public static function Include_Smoothscroll(){
		// I need jquery first.
		self::IncludeJQuery();

		Router::$DefaultView->addScript('js/jquery/jquery.smooth-scroll.min.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}

	public static function Include_Minimalect(){
		// I need jquery first.
		self::IncludeJQuery();

		Router::$DefaultView->addScript('js/jquery/jquery.minimalect.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}

	public static function Include_Icheck(){
		// I need jquery first.
		self::IncludeJQuery();

		Router::$DefaultView->addStylesheet('css/jquery/jquery.icheck.css');
		Router::$DefaultView->addScript('js/jquery/jquery.icheck.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}
	
    public static function Include_HoverIntent(){
		// I need jquery first.
		self::IncludeJQuery();
		
        Router::$DefaultView->addScript ('js/jquery/jquery.hoverIntent.js');

        // IMPORTANT!  Tells the script that the include succeeded!
        return true;
    }

    public static function Include_Carousel() {
		// I need jquery ui first.
		self::IncludeJQueryUI();

		Router::$DefaultView->addScript ('js/jquery/jquery.jcarousel.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}

	public static function Include_Cycle() {
		// I need jquery ui first.
		self::IncludeJQueryUI();

		Router::$DefaultView->addScript ('js/jquery/jquery.cycle2.js');

		// IMPORTANT!  Tells the script that the include succeeded!
		return true;
	}
}
