<?php

use Core\Router;

/**
 * Button Creator; designed to work with the FormButtonCreator element
 *
 * @param $params
 * @param $smarty
 * @return string
 */
function smarty_function_buttoncreator($params, $smarty) {

	$view = Router::$DefaultView;
	$assign     = $params['assign'] ?: null;

	// Check for a single parameter
	if(isset($params[0])) {
		$buttonData = array_shift($params);
	}
	else {
		$buttonData = [];
	}

	// Every button is .... a button.
	if(!isset($buttonData['class'])) {
		$buttonData['class'] = 'button';
	}
	else {
		$buttonData['class'] .= ' button';
	}

	// Merge everything into a single data source
	foreach($params as $key => $val) {
		if($key === 'class') {
			$buttonData['class'] .= ' ' . $val;
		}
		else {
			$buttonData[ $key ] = $val;
		}
	}

	// Strip out other parameters
	if(isset($buttonData['text'])) {
		$text = $buttonData['text'];
		unset($buttonData['text']);
	}
	else {
		$text = 'Click Here';
	}

	// Ensure each button has an ID
	if(!isset($buttonData['id'])) {
		$buttonData['id'] = 'button-' . \Core\random_hex(4);
	}

	// Compile the fully resolved HREF
	if(isset($buttonData['href'])) {
		$buttonData['href'] = \Core\resolve_link($buttonData['href']);
	}

	// The size attribute is weird.
	if(isset($buttonData['size'])) {
		if(!empty($buttonData['size'])) {
			$buttonData['class'] .= ' ' . 'button-size-' . $buttonData['size'];
		}
		unset($buttonData['size']);
	}

	// Compile CSS parameters
	$css = [];
	if(isset($buttonData['color'])) {
		$css[] = '#' . $buttonData['id'] . ',#' . $buttonData['id'] . ' span{color:' . $buttonData['color'] . ';}';
		unset($buttonData['color']);
	}
	if(isset($buttonData['background_color'])) {
		$css[] = '#' . $buttonData['id'] . ',#' . $buttonData['id'] . ' span{background-color:' . $buttonData['background_color'] . ';}';
		unset($buttonData['background_color']);
	}
	if(isset($buttonData['color_hover'])) {
		$css[] = '#' . $buttonData['id'] . ':hover,#' . $buttonData['id'] . ':hover span{color:' . $buttonData['color_hover'] . ';}';
		unset($buttonData['color_hover']);
	}
	if(isset($buttonData['background_color_hover'])) {
		$css[] = '#' . $buttonData['id'] . ':hover,#' . $buttonData['id'] . ':hover span{background-color:' . $buttonData['background_color_hover'] . ';}';
		unset($buttonData['background_color_hover']);
	}
	if(isset($buttonData['border_color'])) {
		$css[] = '#' . $buttonData['id'] . '{border-color:' . $buttonData['border_color'] . ';}';
		unset($buttonData['border_color']);
	}
	if(isset($buttonData['border_color_hover'])) {
		$css[] = '#' . $buttonData['id'] . ':hover{border-color:' . $buttonData['border_color_hover'] . ';}';
		unset($buttonData['border_color_hover']);
	}


	// Now everthing can be compiled!
	if(count($css)) {
		$view->addStyle(implode('', $css));
	}
	$html = '<a ' . \Core\array_to_html_attributes_string($buttonData) . '>' . $text . '</a>';

	if($assign) {
		$smarty->assign($assign, $html);
		return '';
	}
	else {
		return $html;
	}
}