<?php
/**
 * @package Core\Templates\Smarty
 * @since 2.1.3
 * @author Charlie Powell <charlie@evalagency.com>
 * @copyright Copyright (C) 2009-2017  Charlie Powell
 * @license GNU Affero General Public License v3 <http://www.gnu.org/licenses/agpl-3.0.txt>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/agpl-3.0.txt.
 */

/**
 * Load a template while preserving all parent scope variables.
 *
 * Unlike {include ...}, this supports cross engine includes via Core's built-in templating system.
 *
 * @param array  $params  Associative (and/or indexed) array of smarty parameters passed in from the template
 * @param Smarty $smarty  Parent Smarty template object
 *
 * @throws SmartyException
 * @throws Exception
 *
 * @return string
 */
function smarty_function_template($params, $smarty){

	if(array_key_exists('template', $params)){
		$file = $params['template'];
	}
	elseif(array_key_exists('file', $params)) {
		$file = $params['file'];
	}
	elseif(isset($params[0])){
		$file = $params[0];
	}
	else{
		throw new SmartyException('Please set a file to include when using {template}');
	}

	$template = \Core\Templates\Template::Factory($file);
	foreach($smarty->getTemplateVars() as $key => $val) {
		$template->assign($key, $val);
	}
	$ret = $template->fetch();

	if(isset($params['assign']) && $params['assign']){
		$smarty->assign($params['assign'], $ret);
	}
	else{
		return $ret;
	}
}
