{**
 * Helper template for /user/me and /user/view/N to render the sidebar that contains
 * most of the user attributes, particularly those that are short.
 *
 * Expected variables:
 * 
 * $user UserModel of the requested user.
 *}

<ul>
	<li class="user-field-avatar">
		{img src="`$user.avatar`" placeholder="person" dimensions="150x150"}
	</li>
	
	<li class="user-field-username">
		{if $user.first_name || $user.last_name}
			{$user->get('first_name', 'text/html')} {$user->get('last_name', 'text/html')}
		{else}
			{$user->getDisplayName()}
		{/if}
	</li>
	
	<li class="user-field-active">
		{$user->get('active', 'text/html')}
		{if $user.active == 1}
			Activated
		{elseif $user.active == 0}
			Never Active (Contact Only)
		{else}
			Deactivated
		{/if}
	</li>

	{if $user->active == 1}
		{foreach $user->getEnabledAuthDrivers() as $driver}
			<li class="user-field-auth">
				<span class="label">
					Login Method:
				</span>

				<i class="icon icon-{$driver->getAuthIcon()}"></i>
				<span>{$driver->getAuthTitle()}</span>
			</li>
		{foreachelse}
			<li class="user-field-auth error">
				<i class="icon icon-exclamation-triangle"></i>
				<span>No Auth Backend Enabled</span>
			</li>
		{/foreach}
    {/if}
	
	{if $user.email}
		<li class="user-field-email">
			<i class="icon icon-envelope"></i>
			{$user->get('email', 'text/html')}
		</li>
	{/if}
	
	{if $user.email2}
		<li class="user-field-email2">
			<i class="icon icon-envelope"></i>
			{$user->get('email2', 'text/html')}
		</li>
	{/if}
	
	{if $user.email3}
		<li class="user-field-email3">
			<i class="icon icon-envelope"></i>
			{$user->get('email3', 'text/html')}
		</li>
	{/if}
	
	{if $user.phone}
		<li class="user-field-phone">
			<i class="icon icon-phone" title="{t 'STRING_MODEL_USERMODEL_PHONE'}"></i>
			{$user->get('phone', 'text/html')}
		</li>
	{/if}
	
	{if $user.office_phone}
		<li class="user-field-office_phone">
			<i class="icon icon-phone-square" title="{t 'STRING_MODEL_USERMODEL_OFFICE_PHONE'}"></i>
			{$user->get('office_phone', 'text/html')}
		</li>
	{/if}
	
	{if $user.home_phone}
		<li class="user-field-home_phone">
			<i class="icon icon-home" title="{t 'STRING_MODEL_USERMODEL_HOME_PHONE'}"></i>
			{$user->get('home_phone', 'text/html')}
		</li>
	{/if}
	
	{if $user.mobile_phone}
		<li class="user-field-mobile_phone">
			<i class="icon icon-mobile" title="{t 'STRING_MODEL_USERMODEL_MOBILE_PHONE'}"></i>
			{$user->get('mobile_phone', 'text/html')}
		</li>
	{/if}
	
	{if $user.title}
		<li class="user-field-title">
			{$user->get('title', 'text/html')}
		</li>
	{/if}
	
	{if $user.company}
		<li class="user-field-company">
			{$user->get('company', 'text/html')}
		</li>
	{/if}
	
	{foreach $attributes as $k => $dat}
		{if in_array($k, ['avatar', 'title', 'email', 'email2', 'email3', 'active', 'first_name', 'last_name', 'company', 'title', 'phone', 'office_phone', 'mobile_phone', 'home_phone']) }
			{* Skip, already rendered *}
		{elseif $user->get($k) && (strlen($user->get($k)) + strlen($k)) < 38}
			<li class="user-field-{$k}">
				<span class="label">
					{$dat->getTitle()}:
				</span>
				{$user->get($k, 'text/html')}
			</li>
		{/if}
	{/foreach}


{*elseif $user->get($k) && (strlen($user->get($k)) + strlen($k)) >= 38}
			<dt class="user-field-{$k}">{$dat->getTitle()}</dt>
			<dd class="user-field-{$k}">{$user->get($k, 'text/html')}</dd>
		{/if}



	{foreach $user->getEditableFields() as $k => $dat}
		{ A few fields have custom output configurations/layouts. }
		
		{if $k == 'avatar'}
			<li class="user-field-{$k}">{img src="`$dat.value`" placeholder="person" width="150" height="150"}</li>
		{elseif $k == 'email' && $dat.value}
			<li class="user-field-{$k}"><i class="icon icon-envelope" title="{$dat.title}"></i> {$dat.value}</li>
		{elseif $k == 'phone' && $dat.value}
			<li class="user-field-{$k}"><i class="icon icon-phone" title="{$dat.title}"></i> {$dat.value}</li>
		{elseif $k == 'mobile_phone' && $dat.value}
			<li class="user-field-{$k}"><i class="icon icon-mobile" title="{$dat.title}"></i> {$dat.value}</li>
		{elseif $k == 'active'}
			<li class="user-field-{$k}">
				{if $dat.value == 1}
					<i class="icon icon-check"></i> Active
				{else}
					<i class="icon icon-times"></i> Inactive
				{/if}
			</li>
		{elseif $k == 'admin' && $dat.value}
			<li class="user-field-{$k}">
				<i class="icon icon-star"></i> Super Admin
			</li>
		{elseif (strlen($dat.title) + strlen($dat.value)) < 38 && $dat.value}
			<li class="user-field-{$k}">{$dat.title}: {$user->get($k, 'text/html')}</li>
		{/if}
	{/foreach*}

	<li>
		<span class="label">Member Since:</span>
		{date format="FD" $user.created}
	</li>
	{if $user.gpg_pubkey}
		<li>
			<span class="label">GPG Key:</span>
			{gpg_fingerprint $user.gpg_pubkey short=true}
		</li>
	{/if}

	{if $profiles}
		{foreach $profiles as $profile}
			<li>
				<i class="icon icon-{$profile.type}"></i>
				<a href="{$profile.url}" rel="me" title="{($profile.title) ? $profile.title : $profile.type}" target="_blank">
					{if $profile.title}{$profile.title}{else}{$profile.url}{/if}
				</a>
			</li>
		{/foreach}
	{/if}
</ul>