{css}<style>
	.listing-collection .status-running,
	.listing-collection .status-error,
	.listing-collection .status-completed {
		display: none;
	}
</style>{/css}

<h1>Sync Searchable Data</h1>

<p class="message-tutorial">
	Search indexes are stored at the time of the object's saving so it should remain updated,
	however if you believe something is out of date, you can use this page to resync all search indexes.
</p>

{if count($models)}
	<a href="#" class="button sync-all">
		<span>Sync All Models</span>
	</a>
	<br/><br/>

	<ul class="listing-collection">
		{foreach $models as $model}
			<li class="collection-item" data-model="{$model}">
				<div class="collection-item-title">
					<i class="icon icon-spin icon-spinner status-running"></i>
					<i class="icon icon-exclamation status-error"></i>
					<i class="icon icon-check status-completed"></i>
					{$model}
				</div>
				<div class="collection-item-description">

				</div>
				<div class="collection-item-controls">
					<a href="#" class="button sync-model" data-model="{$model}">
						<span>Sync</span>
					</a>
				</div>
			</li>
		{/foreach}
	</ul>
{else}
	<p class="message-info">
		There does not seem to be any indexable data present.
	</p>
{/if}

{script location="foot"}<script>
	(() => {
		let queue = [];

		function syncModel(model) {
			let record = document.querySelector('.collection-item[data-model="' + model + '"]'),
				iconRunning = record.querySelector('.status-running'),
				iconError = record.querySelector('.status-error'),
				iconCompleted = record.querySelector('.status-completed'),
				description = record.querySelector('.collection-item-description');

			iconRunning.style.display = 'inline-block';
			iconError.style.display = 'none';
			iconCompleted.style.display = 'none';

			fetch(
				Core.ROOT_URL + 'admin/syncsearchindex.json?model=' + model,
				{
					method: 'POST'
				}
			)
				.then(res => {
					iconRunning.style.display = 'none';
					return res.json();
				})
				.then(data => {
					if(data.code !== 200) {
						iconError.style.display = 'inline-block';
						description.innerHTML = '<p class="message-error">' + data.message + '</p>';
					}
					else {
						iconCompleted.style.display = 'inline-block';
					}

					if(typeof(Core.DevTools) !== 'undefined' && typeof(data._debug) !== 'undefined') {
						Core.DevTools.SetPageDetails(data._debug.page);
					}

					performSync();
				})
				.catch(er => {
					iconRunning.style.display = 'none';
					iconError.style.display = 'inline-block';
					description.innerHTML = '<p class="message-error">' + er.message + '</p>';

					performSync();
				});
		}

		function performSync() {
			if(!queue.length) {
				return;
			}

			syncModel(queue.shift());
		}

		document.querySelector('.sync-all').addEventListener('click', evt => {
			queue = [];
			document.querySelectorAll('.collection-item').forEach(el => {
				queue.push(el.dataset.model);
			});

			performSync();
			evt.preventDefault();
		});

		document.querySelectorAll('.sync-model').forEach(el => {
			el.addEventListener('click', evt => {
				queue.push(el.dataset.model);
				performSync();
				evt.preventDefault();
			});
		});
	})();
</script>{/script}